@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 #
 # Copyright 2014 Google Inc. All rights reserved.
 #
@@ -59,7 +59,8 @@ class UnicodeDataTest(unittest.TestCase):
         """Tests the is_defined() method."""
         self.assertTrue(unicode_data.is_defined(0x20BD))
         self.assertFalse(unicode_data.is_defined(0xFDD0))
-        self.assertFalse(unicode_data.is_defined(0x088F))
+        # This sometimes snaps when new codepoints are assigned
+        self.assertFalse(unicode_data.is_defined(0x0892))
         # CJK ranges
         self.assertTrue(unicode_data.is_defined(0x3400))
         self.assertTrue(unicode_data.is_defined(0x4DB5))
